/*------------------------------------------------------------------------------
-- This file is a part of the QLop Software
-- Copyright (C) 2015, Plasma Physics Laboratory - CNRS
--
-- This program is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to the Free Software
-- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-------------------------------------------------------------------------------*/
/*-- Author : Alexis Jeandet
-- Mail : alexis.jeandet@member.fsf.org
----------------------------------------------------------------------------*/

#ifndef FILEDOWNLOADERTASK_H
#define FILEDOWNLOADERTASK_H

#include <QObject>
#include <QByteArray>
#include <QNetworkAccessManager>
#include <QNetworkRequest>
#include <QNetworkReply>
#include <QFile>
#include <QDateTime>

// TODO add download speed and remaining time.

class FileDownloaderTask : public QObject
{
    Q_OBJECT
public:
    explicit FileDownloaderTask(QNetworkReply* reply,int ID,const QString& fileName,QObject *parent = 0);
    ~FileDownloaderTask();
    int ID();
    const QString& fileName();
    const QString& url();
    const QDateTime& startDateTime();
    bool downloadComplete();
signals:
    void updateProgress(int percent);
    void updateProgress(qint64 bytesSent, qint64 bytesTotal);
public slots:

private slots:
    void downloadProgress(qint64 bytesSent, qint64 bytesTotal);
    void readReady();
    void downloadFinished();
private:
    int m_taskId;
    QNetworkReply* m_Reply;
    QByteArray m_DownloadedData;
    bool m_downloadComplete;
    QFile* m_file;
    QString m_FileName;
    QString m_URL;
    QDateTime m_startDateTime;
};

#endif // FILEDOWNLOADERTASK_H
